import warnings
import functools


def deprecated(message):
    def decorator(func):
        @functools.wraps(func)
        async def wrapper(*args, **kwargs):
            warnings.warn(
                f"{func.__name__} is deprecated: {message}",
                DeprecationWarning,
                stacklevel=2
            )
            return await func(*args, **kwargs)

        return wrapper

    return decorator



import asyncio
from tikhub import Client


async def main():
    client = Client(base_url="https://beta.tikhub.io", api_key="l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw==")

    # 请求用户信息 | Request user info
    user_info = await client.TikHubUser.get_user_info()
    print(user_info)

    # 请求用户每日使用情况 | Request user daily usage
    user_daily_usage = await client.TikHubUser.get_user_daily_usage()
    print(user_daily_usage)

    # 计算价格 | Calculate price
    price = await client.TikHubUser.calculate_price(endpoint="/api/v1/douyin/app/v1/fetch_one_video", request_per_day=100)
    print(price)

    # 获取阶梯式折扣百分比信息 | Get tiered discount percentage information
    tiered_discount_info = await client.TikHubUser.get_tiered_discount_info()
    print(tiered_discount_info)

    # 获取一个端点的信息 | Get information of an endpoint
    endpoint_info = await client.TikHubUser.get_endpoint_info(endpoint="/api/v1/douyin/app/v1/fetch_one_video")
    print(endpoint_info)

    # 获取所有端点信息 | Get all endpoints information
    all_endpoints_info = await client.TikHubUser.get_all_endpoints_info()
    print(all_endpoints_info)


asyncio.run(main())



# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class DouyinWeb:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据 | Get single video data
    async def fetch_one_video(self, aweme_id: str):
        """
        获取单个作品数据 | Get single video data
        :param aweme_id: 作品id | Video id
        :return: 作品数据 | Video data
        """
        endpoint = "/api/v1/douyin/web/fetch_one_video"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}")
        return data

    # 获取单个作品视频弹幕数据 | Get single video danmaku data
    async def fetch_one_video_danmaku(self, item_id: str, duration: int, end_time: int, start_time: int):
        """
        获取单个作品视频弹幕数据 | Get single video danmaku data
        :param item_id: 作品id | Video id
        :param duration: 视频总时长 | Video total duration
        :param end_time: 结束时间 | End time
        :param start_time: 开始时间 | Start time
        :return: 视频弹幕数据 | Video danmaku data
        """
        endpoint = "/api/v1/douyin/web/fetch_one_video_danmaku"
        data = await self.client.fetch_get_json(
            f"{endpoint}?item_id={item_id}&duration={duration}&end_time={end_time}&start_time={start_time}")
        return data

    # 获取用户主页作品数据 | Get user homepage video data
    async def fetch_user_post_videos(self, sec_user_id: str, max_cursor: int, count: int):
        """
        获取用户主页作品数据 | Get user homepage video data
        :param sec_user_id: 用户sec_user_id | User sec_user_id
        :param max_cursor: 最大游标 | Maximum cursor
        :param count: 最大数量 | Maximum count number
        :return: 用户作品数据 | User video data
        """
        endpoint = "/api/v1/douyin/web/fetch_user_post_videos"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&count={count}")
        return data

    # 获取用户喜欢作品数据 | Get user like video data
    async def fetch_user_like_videos(self, sec_user_id: str, max_cursor: int, counts: int):
        """
        获取用户喜欢作品数据 | Get user like video data
        :param sec_user_id: 用户sec_user_id | User sec_user_id
        :param max_cursor: 最大游标 | Maximum cursor
        :param counts: 最大数量 | Maximum count number
        :return: 用户作品数据 | User video data
        """
        endpoint = "/api/v1/douyin/web/fetch_user_like_videos"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&counts={counts}")
        return data

    # 获取用户收藏作品数据 | Get user collection video data
    async def fetch_user_collection_videos(self, cookie: str, max_cursor: int, counts: int):
        """
        获取用户收藏作品数据 | Get user collection video data
        :param cookie: 用户网页版抖音Cookie | Your web version of Douyin Cookie
        :param max_cursor: 最大游标 | Maximum cursor
        :param counts: 最大数量 | Maximum count number
        :return: 用户作品数据 | User video data
        """
        endpoint = "/api/v1/douyin/web/fetch_user_collection_videos"
        data = await self.client.fetch_get_json(
            f"{endpoint}?cookie={cookie}&max_cursor={max_cursor}&counts={counts}")
        return data

    # 获取用户合辑作品数据 | Get user mix video data
    async def fetch_user_mix_videos(self, mix_id: str, max_cursor: int, counts: int):
        """
        获取用户合辑作品数据 | Get user mix video data
        :param mix_id: 合辑id | Mix id
        :param max_cursor: 最大游标 | Maximum cursor
        :param counts: 最大数量 | Maximum count number
        :return: 用户作品数据 | User video data
        """
        endpoint = "/api/v1/douyin/web/fetch_user_mix_videos"
        data = await self.client.fetch_get_json(
            f"{endpoint}?mix_id={mix_id}&max_cursor={max_cursor}&counts={counts}")
        return data

    # 获取用户直播流数据 | Get user live video data
    async def fetch_user_live_videos(self, webcast_id: str):
        """
        获取用户直播流数据 | Get user live video data
        :param webcast_id: 直播间webcast_id | Room webcast_id
        :return: 直播流数据 | Live stream data
        """
        endpoint = "/api/v1/douyin/web/fetch_user_live_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?webcast_id={webcast_id}")
        return data

    # 获取指定用户的直播流数据 | Get live video data of specified user
    async def fetch_user_live_videos_by_room_id(self, room_id: str):
        """
        获取指定用户的直播流数据 | Get live video data of specified user
        :param room_id: 直播间room_id | Room room_id
        :return: 直播流数据 | Live stream data
        """
        endpoint = "/api/v1/douyin/web/fetch_user_live_videos_by_room_id"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}")
        return data

    # 获取直播间送礼用户排行榜 | Get live room gift user ranking
    async def fetch_live_gift_ranking(self, room_id: str, rank_type: int):
        """
        获取直播间送礼用户排行榜 | Get live room gift user ranking
        :param room_id: 直播间room_id | Room room_id
        :param rank_type: 排行类型 | Leaderboard type
        :return: 排行榜数据 | Leaderboard data
        """
        endpoint = "/api/v1/douyin/web/fetch_live_gift_ranking"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}&rank_type={rank_type}")
        return data

    # 抖音直播间商品信息 | Douyin live room product information
    async def fetch_live_room_product_result(self, room_id: str, author_id: str, limit: int):
        """
        抖音直播间商品信息 | Douyin live room product information
        :param room_id: 直播间room_id | Room room_id
        :param author_id: 作者id | Author id
        :param limit: 数量 | Number
        :return: 商品信息 | Product information
        """
        endpoint = "/api/v1/douyin/web/fetch_live_room_product_result"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}&author_id={author_id}&limit={limit}")
        return data

    # 获取指定用户的信息 | Get information of specified user
    async def handler_user_profile(self, sec_user_id: str):
        """
        获取指定用户的信息 | Get information of specified user
        :param sec_user_id: 用户sec_user_id | User sec_user_id
        :return: 用户信息 | User information
        """
        endpoint = "/api/v1/douyin/web/handler_user_profile"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}")
        return data

    # 获取单个视频评论数据 | Get single video comments data
    async def fetch_video_comments(self, aweme_id: str, cursor: int, count: int):
        """
        获取单个视频评论数据 | Get single video comments data
        :param aweme_id: 作品id | Video id
        :param cursor: 游标 | Cursor
        :param count: 数量 | Number
        :return: 评论数据 | Comments data
        """
        endpoint = "/api/v1/douyin/web/fetch_video_comments"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定视频的评论回复数据 | Get comment replies data of specified video
    async def fetch_video_comments_reply(self, item_id: str, comment_id: str, cursor: int, count: int):
        """
        获取指定视频的评论回复数据 | Get comment replies data of specified video
        :param item_id: 作品id | Video id
        :param comment_id: 评论id | Comment id
        :param cursor: 游标 | Cursor
        :param count: 数量 | Number
        :return: 评论回复数据 | Comment replies data
        """
        endpoint = "/api/v1/douyin/web/fetch_video_comment_replies"
        data = await self.client.fetch_get_json(
            f"{endpoint}?item_id={item_id}&comment_id={comment_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
    async def fetch_general_search_result(self, keyword: str, offset: int, count: int, sort_type: str,
                                          publish_time: str, filter_duration: str):
        """
        获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
        :param keyword: 关键词 | Keyword
        :param offset: 偏移量 | Offset
        :param count: 数量 | Number
        :param sort_type: 0:综合排序 1:最多点赞 2:最新发布 | 0: Comprehensive sorting 1: Most likes 2: Latest release
        :param publish_time: 0:不限 1:最近一天 7:最近一周 180:最近半年 | 0: Unlimited 1: Last day 7: Last week 180: Last half year
        :param filter_duration: 0:不限 0-1:1分钟以内 1-5:1-5分钟 5-10000:5分钟以上 | 0: Unlimited 0-1: Within 1 minute 1-5: 1-5 minutes 5-10000: More than 5 minutes
        :return: 综合搜索结果 | Comprehensive search results
        """
        endpoint = "/api/v1/douyin/web/fetch_general_search_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}&filter_duration={filter_duration}")
        return data

    # 获取指定关键词的视频搜索结果 | Get video search results of specified keywords
    async def fetch_video_search_result(self, keyword: str, offset: int, count: int, sort_type: str, publish_time: str,
                                        filter_duration: str):
        """
        获取指定关键词的视频搜索结果 | Get video search results of specified keywords
        :param keyword: 关键词 | Keyword
        :param offset: 偏移量 | Offset
        :param count: 数量 | Number
        :param sort_type: 0:综合排序 1:最多点赞 2:最新发布 | 0: Comprehensive sorting 1: Most likes 2: Latest release
        :param publish_time: 0:不限 1:最近一天 7:最近一周 180:最近半年 | 0: Unlimited 1: Last day 7: Last week 180: Last half year
        :param filter_duration: 0:不限 0-1:1分钟以内 1-5:1-5分钟 5-10000:5分钟以上 | 0: Unlimited 0-1: Within 1 minute 1-5: 1-5 minutes 5-10000: More than 5 minutes
        :return: 视频搜索结果 | Video search results
        """
        endpoint = "/api/v1/douyin/web/fetch_video_search_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}&filter_duration={filter_duration}")
        return data

    # 获取指定关键词的用户搜索结果 | Get user search results of specified keywords
    async def fetch_user_search_result(self, keyword: str, offset: int, count: int, douyin_user_fans: str,
                                       douyin_user_type: str):
        """
        获取指定关键词的用户搜索结果 | Get user search results of specified keywords
        :param keyword: 关键词 | Keyword
        :param offset: 偏移量 | Offset
        :param count: 数量 | Number
        :param douyin_user_fans: 留空:不限, "0_1k": 1000以下, "1k_1w": 1000-1万, "1w_10w": 1w-10w, "10w_100w": 10w-100w，"100w_": 100w以上
        :param douyin_user_type: 留空:不限, "common_user": 普通用户, "enterprise_user": 企业认证, "personal_user": 个人认证
        :return: 用户搜索结果 | User search results
        """
        endpoint = "/api/v1/douyin/web/fetch_user_search_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&douyin_user_fans={douyin_user_fans}&douyin_user_type={douyin_user_type}")
        return data

    # 获取指定关键词的直播搜索结果 | Get live search results of specified keywords
    async def fetch_live_search_result(self, keyword: str, offset: int, count: int):
        """
        获取指定关键词的直播搜索结果 | Get live search results of specified keywords
        :param keyword: 关键词 | Keyword
        :param offset: 偏移量 | Offset
        :param count: 数量 | Number
        :return: 直播搜索结果 | Live search results
        """
        endpoint = "/api/v1/douyin/web/fetch_live_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取抖音热榜数据 | Get Douyin hot search results
    async def fetch_hot_search_result(self):
        """
        获取抖音热榜数据 | Get Douyin hot search results
        :return: 热榜数据 | Hot search results
        """
        endpoint = "/api/v1/douyin/web/fetch_hot_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 抖音视频频道数据 | Douyin video channel data
    async def fetch_video_channel_result(self, tag_id: int, count: int, refresh_index: int):
        """
        抖音视频频道数据 | Douyin video channel data
        :param tag_id: 标签id | Tag id
        :param count: 数量 | Number
        :param refresh_index: 刷新索引 | Refresh index
        :return: 视频频道数据 | Video channel data
        """
        endpoint = "/api/v1/douyin/web/fetch_video_channel_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?tag_id={tag_id}&count={count}&refresh_index={refresh_index}")
        return data

    # 获取抖音Web的游客Cookie | Get the guest Cookie of Douyin Web
    async def fetch_douyin_web_guest_cookie(self, user_agent: str):
        """
        获取抖音Web的游客Cookie | Get the guest Cookie of Douyin Web
        :param user_agent: 用户浏览器代理 | User browser agent
        :return: 游客Cookie | Guest Cookie
        """
        endpoint = "/api/v1/douyin/web/fetch_douyin_web_guest_cookie"
        data = await self.client.fetch_get_json(f"{endpoint}?user_agent={user_agent}")
        return data

    # 生成真实msToken | Generate real msToken
    async def gen_real_msToken(self):
        """
        生成真实msToken | Generate real msToken
        :return: msToken
        """
        endpoint = "/api/v1/douyin/web/generate_real_msToken"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 生成ttwid | Generate ttwid
    async def gen_ttwid(self):
        """
        生成ttwid | Generate ttwid
        :return: ttwid
        """
        endpoint = "/api/v1/douyin/web/generate_ttwid"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 生成verify_fp | Generate verify_fp
    async def gen_verify_fp(self):
        """
        生成verify_fp | Generate verify_fp
        :return: verify_fp
        """
        endpoint = "/api/v1/douyin/web/generate_verify_fp"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 生成s_v_web_id | Generate s_v_web_id
    async def gen_s_v_web_id(self):
        """
        生成s_v_web_id | Generate s_v_web_id
        :return: s_v_web_id
        """
        endpoint = "/api/v1/douyin/web/generate_s_v_web_id"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 使用接口地址生成Xbogus参数 | Generate Xbogus parameters using the interface address
    async def get_x_bogus(self, url: str, user_agent: str):
        """
        使用接口地址生成Xbogus参数 | Generate Xbogus parameters using the interface address
        :param url: 接口地址 | Interface address
        :param user_agent: 用户代理 | User agent
        :return: Xbogus参数 | Xbogus parameters
        """
        endpoint = "/api/v1/douyin/web/generate_x_bogus"
        data = await self.client.fetch_post_json(f"{endpoint}", params={"url": url, "user_agent": user_agent})
        return data

    # 使用接口地址生成Abogus参数 | Generate Abogus parameters using the interface address
    async def get_a_bogus(self, url: str, data: str, user_agent: str, index_0: int, index_1: int, index_2: int):
        """
        使用接口地址生成Abogus参数 | Generate Abogus parameters using the interface address
        :param url: 接口地址，需要使用urlencode(data, safe="*")进行编码 | Interface address, need to be encoded using urlencode(data, safe="*")
        :param data: body，需要使用urlencode(data, safe="*")进行编码 | body, need to be encoded using urlencode(data, safe="*")
        :param user_agent: user-agent
        :param index_0: 加密明文列表的第一个值，无特殊要求，默认为0，不要随意修改 | The first value of the encryption plaintext list, no special requirements, the default is 0, do not modify it at will
        :param index_1: 加密明文列表的第二个值，无特殊要求，默认为1，不要随意修改 | The second value of the encryption plaintext list, no special requirements, the default is 1, do not modify it at will
        :param index_2: 加密明文列表的第三个值，无特殊要求，默认为14，不要随意修改 | The third value of the encryption plaintext list, no special requirements, the default is 14, do not modify it at will
        :return: Abogus参数 | Abogus parameters
        """
        endpoint = "/api/v1/douyin/web/generate_a_bogus"
        data = await self.client.fetch_post_json(
            f"{endpoint}",
            params={"url": url, "data": data, "user_agent": user_agent, "index_0": index_0, "index_1": index_1,
                    "index_2": index_2})
        return data

    # 提取单个用户id | Extract single user id
    async def get_sec_user_id(self, url: str):
        """
        提取单个用户id | Extract single user id
        :param url: 用户主页链接 | User homepage link
        :return: 用户sec_user_id
        """
        endpoint = "/api/v1/douyin/web/get_sec_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 提取列表用户id | Extract list user id
    async def get_all_sec_user_id(self, url: list):
        """
        提取列表用户id | Extract list user id
        :param url: 用户主页链接列表（最多支持20个链接） | User homepage link list (supports up to 20 links)
        :return: 用户sec_user_id列表 | User sec_user_id list
        """
        endpoint = "/api/v1/douyin/web/get_all_sec_user_id"
        data = await self.client.fetch_post_json(f"{endpoint}", data=json.dumps(url))
        return data

    # 提取单个作品id | Extract single video id
    async def get_aweme_id(self, url: str):
        """
        提取单个作品id | Extract single video id
        :param url: 作品链接 | Video link
        :return: 作品id | Video id
        """
        endpoint = "/api/v1/douyin/web/get_aweme_id"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 提取列表作品id | Extract list video id
    async def get_all_aweme_id(self, url: list):
        """
        提取列表作品id | Extract list video id
        :param url: 作品链接列表（最多支持20个链接） | Video link list (supports up to 20 links)
        :return: 作品id列表 | Video id list
        """
        endpoint = "/api/v1/douyin/web/get_all_aweme_id"
        data = await self.client.fetch_post_json(f"{endpoint}", data=json.dumps(url))
        return data

    # 提取直播间号 | Extract webcast id
    async def get_webcast_id(self, url: str):
        """
        提取直播间号 | Extract webcast id
        :param url: 直播间链接 | Room link
        :return: 直播间号 | Room id
        """
        endpoint = "/api/v1/douyin/web/get_webcast_id"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 提取列表直播间号 | Extract list webcast id
    async def get_all_webcast_id(self, url: list):
        """
        提取列表直播间号 | Extract list webcast id
        :param url: 直播间链接列表（最多支持20个链接） | Room link list (supports up to 20 links)
        :return: 直播间号列表 | Room id list
        """
        endpoint = "/api/v1/douyin/web/get_all_webcast_id"
        # 将列表转换为json格式 | Convert the list to json format
        data = await self.client.fetch_post_json(f"{endpoint}", data=json.dumps(url))
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer jZVuQT5gm2gDj3IB0XKPySMV9B4EmLfyqo5okGfltWp7/VAgQt8unAaMEA=="})

        douyin_web = DouyinWeb(client)

        # 获取单个作品数据 | Get single video data
        # data = await douyin_web.fetch_one_video("7345492945006595379")
        # print(f"fetch_one_video: {data}")

        # 获取单个作品视频弹幕数据 | Get single video danmaku data
        # data = await douyin_web.fetch_one_video_danmaku("7355433624046472498", 15134, 15133, 0)
        # print(f"fetch_one_video_danmaku: {data}")

        # 获取用户主页作品数据 | Get user homepage video data
        # data = await douyin_web.fetch_user_post_videos("MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY", 0, 10)
        # print(f"fetch_user_post_videos: {data}")

        # 获取用户喜欢作品数据 | Get user like video data
        # data = await douyin_web.fetch_user_like_videos("MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY", 0, 10)
        # print(f"fetch_user_like_videos: {data}")

        # 获取用户收藏作品数据 | Get user collection video data
        # data = await douyin_web.fetch_user_collection_videos("cookie", 0, 10)
        # print(f"fetch_user_collection_videos: {data}")

        # 获取用户合辑作品数据 | Get user mix video data
        # data = await douyin_web.fetch_user_mix_videos("MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY", 0, 10)
        # print(f"fetch_user_mix_videos: {data}")

        # 获取用户直播流数据 | Get user live video data
        # data = await douyin_web.fetch_user_live_videos("MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY")
        # print(f"fetch_user_live_videos: {data}")

        # 获取指定用户的直播流数据 | Get live video data of specified user
        # data = await douyin_web.fetch_user_live_videos_by_room_id("6958745176821132813")
        # print(f"fetch_user_live_videos_by_room_id: {data}")

        # 获取直播间送礼用户排行榜 | Get live room gift user ranking
        # data = await douyin_web.fetch_live_gift_ranking("6958745176821132813", 1)
        # print(f"fetch_live_gift_ranking: {data}")

        # 抖音直播间商品信息 | Douyin live room product information
        # data = await douyin_web.fetch_live_room_product_result("6958745176821132813", "6958745176821132813", 10)
        # print(f"fetch_live_room_product_result: {data}")

        # 获取指定用户的信息 | Get information of specified user
        # data = await douyin_web.handler_user_profile("MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY")
        # print(f"handler_user_profile: {data}")

        # 获取单个视频评论数据 | Get single video comments data
        # data = await douyin_web.fetch_video_comments("7355433624046472498", 0, 10)
        # print(f"fetch_video_comments: {data}")

        # 获取指定视频的评论回复数据 | Get comment replies data of specified video
        # data = await douyin_web.fetch_video_comments_reply("7355433624046472498", "7355433624046472498", 0, 10)
        # print(f"fetch_video_comments_reply: {data}")

        # 获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
        # data = await douyin_web.fetch_general_search_result("抖音", 0, 10, "0", "0", "0")
        # print(f"fetch_general_search_result: {data}")

        # 获取指定关键词的视频搜索结果 | Get video search results of specified keywords
        # data = await douyin_web.fetch_video_search_result("抖音", 0, 10, "0", "0", "0")
        # print(f"fetch_video_search_result: {data}")

        # 获取指定关键词的用户搜索结果 | Get user search results of specified keywords
        # data = await douyin_web.fetch_user_search_result("抖音", 0, 10, "", "")
        # print(f"fetch_user_search_result: {data}")

        # 获取指定关键词的直播搜索结果 | Get live search results of specified keywords
        # data = await douyin_web.fetch_live_search_result("抖音", 0, 10)
        # print(f"fetch_live_search_result: {data}")

        # 获取抖音热榜数据 | Get Douyin hot search results
        # data = await douyin_web.fetch_hot_search_result()
        # print(f"fetch_hot_search_result: {data}")

        # 抖音视频频道数据 | Douyin video channel data
        # data = await douyin_web.fetch_video_channel_result(0, 10, 0)
        # print(f"fetch_video_channel_result: {data}")

        # 获取抖音Web的游客Cookie | Get the guest Cookie of Douyin Web
        # data = await douyin_web.fetch_douyin_web_guest_cookie("Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/58.0.3029.110 Safari/537.3")
        # print(f"fetch_douyin_web_guest_cookie: {data}")

        # 生成真实msToken | Generate real msToken
        # data = await douyin_web.gen_real_msToken()
        # print(f"gen_real_msToken: {data}")

        # 生成ttwid | Generate ttwid
        # data = await douyin_web.gen_ttwid()
        # print(f"gen_ttwid: {data}")

        # 生成verify_fp | Generate verify_fp
        # data = await douyin_web.gen_verify_fp()
        # print(f"gen_verify_fp: {data}")

        # 生成s_v_web_id | Generate s_v_web_id
        # data = await douyin_web.gen_s_v_web_id()
        # print(f"gen_s_v_web_id: {data}")

        # 使用接口地址生成Xbogus参数 | Generate Xbogus parameters using the interface address
        # data = await douyin_web.get_x_bogus("https://www.douyin.com/aweme/v1/web/aweme/detail/?aweme_id=7148736076176215311&device_platform=webapp&aid=6383&channel=channel_pc_web&pc_client_type=1&version_code=170400&version_name=17.4.0&cookie_enabled=true&screen_width=1920&screen_height=1080&browser_language=zh-CN&browser_platform=Win32&browser_name=Edge&browser_version=117.0.2045.47&browser_online=true&engine_name=Blink&engine_version=",
        #                                   "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36")
        # print(f"get_x_bogus: {data}")

        # 使用接口地址生成Abogus参数 | Generate Abogus parameters using the interface address
        # data = await douyin_web.get_a_bogus("https://www.douyin.com/aweme/v1/web/aweme/detail/?aweme_id=7148736076176215311&device_platform=webapp&aid=6383&channel=channel_pc_web&pc_client_type=1&version_code=170400&version_name=17.4.0&cookie_enabled=true&screen_width=1920&screen_height=1080&browser_language=zh-CN&browser_platform=Win32&browser_name=Edge&browser_version=117.0.2045.47&browser_online=true&engine_name=Blink&engine_version=",
        #                                   "",
        #                                     "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/90.0.4430.212 Safari/537.36",
        #                                     0,
        #                                     1,
        #                                     14,
        #                                     )
        # print(f"get_a_bogus: {data}")

        # 提取单个用户id | Extract single user id
        # data = await douyin_web.get_sec_user_id("https://www.douyin.com/user/MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY")
        # print(f"get_sec_user_id: {data}")

        # 提取列表用户id | Extract list user id
        # data = await douyin_web.get_all_sec_user_id(["https://www.douyin.com/user/MS4wLjABAAAA6Zb5Z5Vv4X3v4VH9VX1z3Y0QV2z6FyJQJ8Q2H3J9zY"])
        # print(f"get_all_sec_user_id: {data}")

        # 提取单个作品id | Extract single video id
        # data = await douyin_web.get_aweme_id("https://www.douyin.com/video/7355433624046472498")
        # print(f"get_aweme_id: {data}")

        # 提取列表作品id | Extract list video id
        # data = await douyin_web.get_all_aweme_id(["https://www.douyin.com/video/7355433624046472498"])
        # print(f"get_all_aweme_id: {data}")

        # 提取直播间号 | Extract webcast id
        # data = await douyin_web.get_webcast_id("https://v.douyin.com/i8tBR7hX/")
        # print(f"get_webcast_id: {data}")

        # 提取列表直播间号 | Extract list webcast id
        # data = await douyin_web.get_all_webcast_id([
        #     "https://live.douyin.com/775841227732",
        #     "https://live.douyin.com/775841227732?room_id=7318296342189919011&enter_from_merge=web_share_link&enter_method=web_share_link&previous_page=app_code_link",
        #     "https://webcast.amemv.com/douyin/webcast/reflow/7318296342189919011?u_code=l1j9bkbd&did=MS4wLjABAAAAEs86TBQPNwAo-RGrcxWyCdwKhI66AK3Pqf3ieo6HaxI&iid=MS4wLjABAAAA0ptpM-zzoliLEeyvWOCUt-_dQza4uSjlIvbtIazXnCY&with_sec_did=1&use_link_command=1&ecom_share_track_params=&extra_params={\"from_request_id\":\"20231230162057EC005772A8EAA0199906\",\"im_channel_invite_id\":\"0\"}&user_id=3644207898042206&liveId=7318296342189919011&from=share&style=share&enter_method=click_share&roomId=7318296342189919011&activity_info={}",
        #     "6i- Q@x.Sl 03/23 【醒子8ke的直播间】  点击打开👉https://v.douyin.com/i8tBR7hX/  或长按复制此条消息，打开抖音，看TA直播",
        #     "https://v.douyin.com/i8tBR7hX/"
        # ])
        # print(f"get_all_webcast_id: {data}")


    # 运行异步事件循环 | Run asynchronous event loop
    asyncio.run(main())



# 导入API SDK Client类

from tikhub.http_client.api_client import APIClient

# 标记已废弃的方法
from tikhub.http_client.deprecated import deprecated


class DouyinAppV3:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据
    async def fetch_one_video(self, aweme_id: str):
        endpoint = f"/api/v1/douyin/app/v3/fetch_one_video"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}")
        return data

    # 根据分享链接获取作品数据 | Get video data by sharing url
    async def fetch_one_video_by_share_url(self, share_url: str):
        endpoint = "/api/v1/douyin/app/v3/fetch_one_video_by_share_url"
        data = await self.client.fetch_get_json(f"{endpoint}?share_url={share_url}")
        return data

    # 获取指定用户的信息
    async def handler_user_profile(self, sec_user_id: str):
        endpoint = f"/api/v1/douyin/app/v3/handler_user_profile"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}")
        return data

    # 获取用户作品集合数据
    async def fetch_user_post_videos(self, sec_user_id: str, max_cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_user_post_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&count={count}")
        return data

    # 获取用户喜欢作品数据
    async def fetch_user_like_videos(self, sec_user_id: str, max_cursor: int, counts: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_user_like_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&counts={counts}")
        return data

    # 获取单个视频评论数据
    async def fetch_video_comments(self, aweme_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_video_comments"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定视频的评论回复数据
    async def fetch_video_comments_reply(self, item_id: str, comment_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_video_comment_replies"
        data = await self.client.fetch_get_json(f"{endpoint}?item_id={item_id}&comment_id={comment_id}&cursor={cursor}&count={count}")
        return data

    # 抖音视频合集详情数据
    async def fetch_video_mix_detail(self, mix_id: str):
        endpoint = f"/api/v1/douyin/app/v3/fetch_video_mix_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?mix_id={mix_id}")
        return data

    # 抖音视频合集作品列表数据
    async def fetch_video_mix_post_list(self, mix_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_video_mix_post_list"
        data = await self.client.fetch_get_json(f"{endpoint}?mix_id={mix_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定关键词的综合搜索结果
    async def fetch_general_search_result(self, keyword: str, offset: int, count: int, sort_type: str, publish_time: str, filter_duration: str, content_type: str):
        endpoint = f"/api/v1/douyin/app/v3/fetch_general_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}&filter_duration={filter_duration}&content_type={content_type}")
        return data

    # 获取指定关键词的视频搜索结果
    async def fetch_video_search_result(self, keyword: str, offset: int, count: int, sort_type: str, publish_time: str, filter_duration: str):
        endpoint = f"/api/v1/douyin/app/v3/fetch_video_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}&filter_duration={filter_duration}")
        return data

    # 获取指定关键词的用户搜索结果
    async def fetch_user_search_result(self, keyword: str, offset: int, count: int, douyin_user_fans: str, douyin_user_type: str):
        endpoint = f"/api/v1/douyin/app/v3/fetch_user_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&douyin_user_fans={douyin_user_fans}&douyin_user_type={douyin_user_type}")
        return data

    # 获取指定关键词的直播搜索结果
    async def fetch_live_search_result(self, keyword: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_live_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&cursor={cursor}&count={count}")
        return data

    # 获取指定关键词的音乐搜索结果
    async def fetch_music_search_result(self, keyword: str, offset: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_music_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定关键词的话题搜索结果
    async def fetch_hashtag_search_result(self, keyword: str, offset: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_hashtag_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定音乐的详情数据
    async def fetch_music_detail(self, music_id: str):
        endpoint = f"/api/v1/douyin/app/v3/fetch_music_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 抖音音乐视频列表结果
    async def fetch_music_video_list(self, music_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_music_video_list"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}&cursor={cursor}&count={count}")
        return data

    # 抖音话题详情数据
    async def fetch_hashtag_detail(self, ch_id: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_hashtag_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?ch_id={ch_id}")
        return data

    # 获取指定话题的作品数据
    async def fetch_hashtag_video_list(self, ch_id: int, cursor: int, sort_type: int, count: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_hashtag_video_list"
        data = await self.client.fetch_get_json(f"{endpoint}?ch_id={ch_id}&cursor={cursor}&sort_type={sort_type}&count={count}")
        return data

    # 抖音热搜榜数据
    async def fetch_hot_search_list(self):
        endpoint = f"/api/v1/douyin/app/v3/fetch_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 抖音直播热搜榜数据
    async def fetch_hot_live_search(self):
        endpoint = f"/api/v1/douyin/app/v3/fetch_live_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 抖音音乐热榜数据
    async def fetch_hot_music_search(self):
        endpoint = f"/api/v1/douyin/app/v3/fetch_music_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 抖音品牌热榜分类数据
    async def fetch_hot_brand_search_category(self):
        endpoint = f"/api/v1/douyin/app/v3/fetch_brand_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 抖音品牌热榜具体分类数据
    async def fetch_hot_brand_search(self, category_id: int):
        endpoint = f"/api/v1/douyin/app/v3/fetch_brand_hot_search_list_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?category_id={category_id}")
        return data

    # 生成抖音短链接
    async def fetch_douyin_short_url(self, url: str):
        endpoint = f"/api/v1/douyin/app/v3/generate_douyin_short_url"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 生成抖音视频分享二维码
    async def fetch_douyin_video_qrcode(self, object_id: str):
        endpoint = f"/api/v1/douyin/app/v3/generate_douyin_video_share_qrcode"
        data = await self.client.fetch_get_json(f"{endpoint}?object_id={object_id}")
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw=="})

        douyin_app_v3 = DouyinAppV3(client)

        # 获取单个作品数据
        data = await douyin_app_v3.fetch_one_video("6954433834136592141")
        print(data)

        # 获取指定用户的信息
        data = await douyin_app_v3.handler_user_profile("MS4wLjABAAAA9VQ5z5zq8s7tjUvJ1nJYwzYz1pQ5Zb1z9z4Q1z4z1o")
        print(data)

        # 获取用户作品集合数据
        data = await douyin_app_v3.fetch_user_post_videos("MS4wLjABAAAA9VQ5z5zq8s7tjUvJ1nJYwzYz1pQ5Zb1z9z4Q1z4z1o", 0, 10)
        print(data)

        # 获取用户喜欢作品数据
        data = await douyin_app_v3.fetch_user_like_videos("MS4wLjABAAAA9VQ5z5zq8s7tjUvJ1nJYwzYz1pQ5Zb1z9z4Q1z4z1o", 0, 10)
        print(data)

        # 获取单个视频评论数据
        data = await douyin_app_v3.fetch_video_comments("6954433834136592141", 0, 10)
        print(data)

        # 获取指定视频的评论回复数据
        data = await douyin_app_v3.fetch_video_comments_reply("6954433834136592141", "6954433834136592141", 0, 10)
        print(data)

        # 抖音视频合集详情数据
        data = await douyin_app_v3.fetch_video_mix_detail("6954433834136592141")
        print(data)

        # 抖音视频合集作品列表数据
        data = await douyin_app_v3.fetch_video_mix_post_list("6954433834136592141", 0, 10)
        print(data)

        # 获取指定关键词的综合搜索结果
        data = await douyin_app_v3.fetch_general_search_result("抖音", 0, 10, "general", "all", "all", "all")
        print(data)

        # 获取指定关键词的视频搜索结果
        data = await douyin_app_v3.fetch_video_search_result("抖音", 0, 10, "general", "all", "all")
        print(data)

        # 获取指定关键词的用户搜索结果
        data = await douyin_app_v3.fetch_user_search_result("抖音", 0, 10, "all", "all")
        print(data)

        # 获取指定关键词的直播搜索结果
        data = await douyin_app_v3.fetch_live_search_result("抖音", 0, 10)
        print(data)

        # 获取指定关键词的音乐搜索结果
        data = await douyin_app_v3.fetch_music_search_result("抖音", 0, 10)
        print(data)

        # 获取指定关键词的话题搜索结果
        data = await douyin_app_v3.fetch_hashtag_search_result("抖音", 0, 10)
        print(data)

        # 获取指定音乐的详情数据
        data = await douyin_app_v3.fetch_music_detail("6954433834136592141")
        print(data)

        # 抖音音乐视频列表结果
        data = await douyin_app_v3.fetch_music_video_list("6954433834136592141", 0, 10)
        print(data)

        # 抖音话题详情数据
        data = await douyin_app_v3.fetch_hashtag_detail(6954433834136592141)
        print(data)

        # 获取指定话题的作品数据
        data = await douyin_app_v3.fetch_hashtag_video_list(6954433834136592141, 0, 0, 10)
        print(data)

        # 抖音热搜榜数据
        data = await douyin_app_v3.fetch_hot_search_list()
        print(data)

        # 抖音直播热搜榜数据
        data = await douyin_app_v3.fetch_hot_live_search()
        print(data)

        # 抖音音乐热榜数据
        data = await douyin_app_v3.fetch_hot_music_search()
        print(data)

        # 抖音品牌热榜分类数据
        data = await douyin_app_v3.fetch_hot_brand_search_category()
        print(data)

        # 抖音品牌热榜具体分类数据
        data = await douyin_app_v3.fetch_hot_brand_search(1)
        print(data)

        # 生成抖音短链接
        data = await douyin_app_v3.fetch_douyin_short_url("https://v.douyin.com/e8e3m5v/")
        print(data)

        # 生成抖音视频分享二维码
        data = await douyin_app_v3.fetch_douyin_video_qrcode("6954433834136592141")
        print(data)


    asyncio.run(main())


# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class TikHubUser:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 根据session_id获取用户信息 | Get TikHub user info
    async def get_user_info(self):
        endpoint = "/api/v1/tikhub/user/get_user_info"
        data = await self.client.fetch_get_json(endpoint)
        return data

    # 获取用户每日使用情况 | Get user daily usage
    async def get_user_daily_usage(self):
        endpoint = "/api/v1/tikhub/user/get_user_daily_usage"
        data = await self.client.fetch_get_json(endpoint)
        return data

    # 计算价格 | Calculate price
    async def calculate_price(self, endpoint: str, request_per_day: int):
        __endpoint = "/api/v1/tikhub/user/calculate_price"
        data = await self.client.fetch_get_json(f"{__endpoint}?endpoint={endpoint}&request_per_day={request_per_day}")
        return data

    # 获取阶梯式折扣百分比信息 | Get tiered discount percentage information
    async def get_tiered_discount_info(self):
        endpoint = "/api/v1/tikhub/user/get_tiered_discount_info"
        data = await self.client.fetch_get_json(endpoint)
        return data

    # 获取一个端点的信息 | Get information of an endpoint
    async def get_endpoint_info(self, endpoint: str):
        __endpoint = "/api/v1/tikhub/user/get_endpoint_info"
        data = await self.client.fetch_get_json(f"{__endpoint}?endpoint={endpoint}")
        return data

    # 获取所有端点信息 | Get all endpoints information
    async def get_all_endpoints_info(self):
        endpoint = "/api/v1/tikhub/user/get_all_endpoints_info"
        data = await self.client.fetch_get_json(endpoint)
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw=="})

        tikhub_user = TikHubUser(client)

        # 根据session_id获取用户信息 | Get TikHub user info
        data = await tikhub_user.get_user_info()
        print(data)

        # 获取用户每日使用情况 | Get user daily usage
        data = await tikhub_user.get_user_daily_usage()
        print(data)

        # 计算价格 | Calculate price
        data = await tikhub_user.calculate_price(endpoint="/api/v1/douyin/app/v1/fetch_one_video",
                                                 request_per_day=100000)
        print(data)

        # 获取阶梯式折扣百分比信息 | Get tiered discount percentage information
        data = await tikhub_user.get_tiered_discount_info()
        print(data)

        # 获取一个端点的信息 | Get information of an endpoint
        data = await tikhub_user.get_endpoint_info(endpoint="/api/v1/douyin/app/v1/fetch_one_video")
        print(data)

        # 获取所有端点信息 | Get all endpoints information
        data = await tikhub_user.get_all_endpoints_info()
        print(data)


    asyncio.run(main())



# 导入API SDK Client类

from tikhub.http_client.api_client import APIClient


class DouyinAppV1:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据 | Get single video data
    async def fetch_one_video(self, aweme_id: str):
        endpoint = f"/api/v1/douyin/app/v1/fetch_one_video?aweme_id={aweme_id}"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}")
        return data

    # 根据分享链接获取作品数据 | Get video data by sharing url
    async def fetch_one_video_by_share_url(self, share_url: str):
        endpoint = "/api/v1/douyin/app/v1/fetch_one_video_by_share_url"
        data = await self.client.fetch_get_json(f"{endpoint}?share_url={share_url}")
        return data

    # 获取指定用户的信息 | Get information of specified user
    async def handler_user_profile(self, sec_user_id: str):
        endpoint = f"/api/v1/douyin/app/v1/handler_user_profile?sec_user_id={sec_user_id}"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}")
        return data

    # 获取用户主页作品数据 | Get user homepage video data
    async def fetch_user_post_videos(self, sec_user_id: str, max_cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_user_post_videos?sec_user_id={sec_user_id}&max_cursor={max_cursor}&count={count}"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&count={count}")
        return data

    # 获取用户喜欢作品数据 | Get user like video data
    async def fetch_user_like_videos(self, sec_user_id: str, max_cursor: int, counts: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_user_like_videos?sec_user_id={sec_user_id}&max_cursor={max_cursor}&counts={counts}"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&counts={counts}")
        return data

    # 获取单个视频评论数据 | Get single video comments data
    async def fetch_video_comments(self, aweme_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_video_comments?aweme_id={aweme_id}&cursor={cursor}&count={count}"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定视频的评论回复数据 | Get comment replies data of specified video
    async def fetch_video_comments_reply(self, item_id: str, comment_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_video_comment_replies?item_id={item_id}&comment_id={comment_id}&cursor={cursor}&count={count}"
        data = await self.client.fetch_get_json(
            f"{endpoint}?item_id={item_id}&comment_id={comment_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
    async def fetch_general_search_result(self, keyword: str, offset: int, count: int, sort_type: int,
                                          publish_time: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_general_search_result?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}")
        return data

    # 获取指定关键词的视频搜索结果 | Get video search results of specified keywords
    async def fetch_video_search_result(self, keyword: str, offset: int, count: int, sort_type: int, publish_time: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_video_search_result?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}")
        return data

    # 获取指定关键词的用户搜索结果 | Get user search results of specified keywords
    async def fetch_user_search_result(self, keyword: str, offset: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_user_search_result?keyword={keyword}&offset={offset}&count={count}"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定关键词的音乐搜索结果 | Get music search results of specified keywords
    async def fetch_music_search_result(self, keyword: str, offset: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_music_search_result?keyword={keyword}&offset={offset}&count={count}"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定关键词的话题搜索结果 | Get hashtag search results of specified keywords
    async def fetch_hashtag_search_result(self, keyword: str, offset: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_hashtag_search_result?keyword={keyword}&offset={offset}&count={count}"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定音乐的详情数据 | Get details of specified music
    async def fetch_music_detail(self, music_id: str):
        endpoint = f"/api/v1/douyin/app/v1/fetch_music_detail?music_id={music_id}"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 获取指定音乐的视频列表数据 | Get video list of specified music
    async def fetch_music_video_list(self, music_id: str, cursor: int, count: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_music_video_list?music_id={music_id}&cursor={cursor}&count={count}"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定话题的详情数据 | Get details of specified hashtag
    async def fetch_hashtag_detail(self, ch_id: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_hashtag_detail?ch_id={ch_id}"
        data = await self.client.fetch_get_json(f"{endpoint}?ch_id={ch_id}")
        return data

    # 获取指定话题的作品数据 | Get video list of specified hashtag
    async def fetch_hashtag_post_list(self, ch_id: int, cursor: int, count: int, sort_type: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_hashtag_video_list?ch_id={ch_id}&cursor={cursor}&count={count}&sort_type={sort_type}"
        data = await self.client.fetch_get_json(
            f"{endpoint}?ch_id={ch_id}&cursor={cursor}&count={count}&sort_type={sort_type}")
        return data

    # 获取抖音热搜榜数据 | Get Douyin hot search list data
    async def fetch_hot_search_list(self):
        endpoint = f"/api/v1/douyin/app/v1/fetch_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 获取抖音直播热搜榜数据 | Get Douyin live hot search list data
    async def fetch_hot_live_search(self):
        endpoint = f"/api/v1/douyin/app/v1/fetch_live_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 获取抖音音乐热榜数据 | Get Douyin music hot search list data
    async def fetch_hot_music_search(self):
        endpoint = f"/api/v1/douyin/app/v1/fetch_music_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 获取抖音品牌热榜分类数据 | Get Douyin brand hot search list data
    async def fetch_hot_brand_search_category(self):
        endpoint = f"/api/v1/douyin/app/v1/fetch_brand_hot_search_list"
        data = await self.client.fetch_get_json(f"{endpoint}")
        return data

    # 获取抖音品牌热榜具体分类数据 | Get Douyin brand hot search list detail data
    async def fetch_hot_brand_search(self, category_id: int):
        endpoint = f"/api/v1/douyin/app/v1/fetch_brand_hot_search_list_detail?category_id={category_id}"
        data = await self.client.fetch_get_json(f"{endpoint}?category_id={category_id}")
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer jZVuQT5gm2gDj3IB0XKPySMV9B4EmLfyqo5okGfltWp7/VAgQt8unAaMEA=="})

        douyin_app_v1 = DouyinAppV1(client)

        # # 获取单个作品数据 | Get single video data
        # data = await douyin_app_v1.fetch_one_video(aweme_id="7345492945006595379")
        # print(f"fetch_one_video: {data}")
        #
        # # 获取指定用户的信息 | Get information of specified user
        # data = await douyin_app_v1.handler_user_profile(
        #     sec_user_id="MS4wLjABAAAAW9FWcqS7RdQAWPd2AA5fL_ilmqsIFUCQ_Iym6Yh9_cUa6ZRqVLjVQSUjlHrfXY1Y")
        # print(f"handler_user_profile: {data}")
        #
        # # 获取用户主页作品数据 | Get user homepage video data
        # data = await douyin_app_v1.fetch_user_post_videos(
        #     sec_user_id="MS4wLjABAAAANXSltcLCzDGmdNFI2Q_QixVTr67NiYzjKOIP5s03CAE", max_cursor=0, count=10)
        # print(f"fetch_user_post_videos: {data}")
        #
        # # 获取用户喜欢作品数据 | Get user like video data
        # data = await douyin_app_v1.fetch_user_like_videos(
        #     sec_user_id="MS4wLjABAAAAW9FWcqS7RdQAWPd2AA5fL_ilmqsIFUCQ_Iym6Yh9_cUa6ZRqVLjVQSUjlHrfXY1Y", max_cursor=0, counts=10)
        # print(f"fetch_user_like_videos: {data}")
        #
        # # 获取单个视频评论数据 | Get single video comments data
        # data = await douyin_app_v1.fetch_video_comments(aweme_id="7345492945006595379", cursor=0, count=10)
        # print(f"fetch_video_comments: {data}")
        #
        # # 获取指定视频的评论回复数据 | Get comment replies data of specified video
        # data = await douyin_app_v1.fetch_video_comments_reply(item_id="7354666303006723354",
        #                                                       comment_id="7354669356632638218",
        #                                                       cursor=0,
        #                                                       count=10)
        # print(f"fetch_video_comments_reply: {data}")
        #
        # # 获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
        # data = await douyin_app_v1.fetch_general_search_result(keyword="中华娘", offset=0, count=20, sort_type=0,
        #                                                        publish_time=0)
        # print(f"fetch_general_search_result: {data}")
        #
        # # 获取指定关键词的视频搜索结果 | Get video search results of specified keywords
        # data = await douyin_app_v1.fetch_video_search_result(keyword="中华娘", offset=0, count=20, sort_type=0,
        #                                                      publish_time=0)
        # print(f"fetch_video_search_result: {data}")
        #
        # # 获取指定关键词的用户搜索结果 | Get user search results of specified keywords
        # data = await douyin_app_v1.fetch_user_search_result(keyword="中华娘", offset=0, count=20)
        # print(f"fetch_user_search_result: {data}")
        #
        # # 获取指定关键词的音乐搜索结果 | Get music search results of specified keywords
        # data = await douyin_app_v1.fetch_music_search_result(keyword="中华娘", offset=0, count=20)
        # print(f"fetch_music_search_result: {data}")
        #
        # # 获取指定关键词的话题搜索结果 | Get hashtag search results of specified keywords
        # data = await douyin_app_v1.fetch_hashtag_search_result(keyword="中华娘", offset=0, count=20)
        # print(f"fetch_hashtag_search_result: {data}")
        #
        # # 获取指定音乐的详情数据 | Get details of specified music
        # data = await douyin_app_v1.fetch_music_detail(music_id="7136850194742315016")
        # print(f"fetch_music_detail: {data}")
        #
        # # 抖音音乐视频列表结果 | Get video list of specified music
        # data = await douyin_app_v1.fetch_music_video_list(music_id="7136850194742315016", cursor=0, count=10)
        # print(f"fetch_music_video_list: {data}")
        #
        # # 抖音话题详情数据 | Get details of specified hashtag
        # data = await douyin_app_v1.fetch_hashtag_detail(ch_id=1575791821492238)
        # print(f"fetch_hashtag_detail: {data}")
        #
        # # 获取指定话题的作品数据 | Get video list of specified hashtag
        # data = await douyin_app_v1.fetch_hashtag_post_list(ch_id=1575791821492238, cursor=0, count=10, sort_type=0)
        # print(f"fetch_hashtag_post_list: {data}")
        #
        # # 抖音热搜榜数据 | Get Douyin hot search list data
        # data = await douyin_app_v1.fetch_hot_search_list()
        # print(f"fetch_hot_search_list: {data}")
        #
        # # 抖音直播热搜榜数据 | Get Douyin live hot search list data
        # data = await douyin_app_v1.fetch_hot_live_search()
        # print(f"fetch_hot_live_search: {data}")
        #
        # # 抖音音乐热榜数据 | Get Douyin music hot search list data
        # data = await douyin_app_v1.fetch_hot_music_search()
        # print(f"fetch_hot_music_search: {data}")
        #
        # # 抖音品牌热榜分类数据 | Get Douyin brand hot search list data
        # data = await douyin_app_v1.fetch_hot_brand_search_category()
        # print(f"fetch_hot_brand_search_category: {data}")
        #
        # # 抖音品牌热榜具体分类数据 | Get Douyin brand hot search list detail data
        # data = await douyin_app_v1.fetch_hot_brand_search(category_id=10)
        # print(f"fetch_hot_brand_search: {data}")

    asyncio.run(main())



import asyncio
from typing import Union, List, Any

import httpx
from httpx import Response

from tikhub.http_client.api_exceptions import (
    APIError,
    APIConnectionError,
    APIResponseError,
    APITimeoutError,
    APIUnavailableError,
    APIUnauthorizedError,
    APINotFoundError,
    APIRateLimitError,
    APIRetryExhaustedError,
)
from tikhub.http_client.api_logger import logger


class APIClient:
    """
    基础API客户端 (Base API http_client)
    """

    def __init__(
            self,
            base_url: str,
            client_headers: dict,
            proxies: dict = None,
            max_retries: int = 3,
            max_connections: int = 50,
            timeout: int = 30,
            max_tasks: int = 50,
    ):
        if isinstance(proxies, dict):
            self.proxies = proxies
            # [f"{k}://{v}" for k, v in proxies.items()]
        else:
            self.proxies = None

        # API基础URL / API base URL
        self.base_url = base_url
        # API请求头 / API request header
        self.client_headers = client_headers

        # 异步的任务数 / Number of asynchronous tasks
        self._max_tasks = max_tasks
        self.semaphore = asyncio.Semaphore(max_tasks)

        # 限制最大连接数 / Limit the maximum number of connections
        self._max_connections = max_connections
        self.limits = httpx.Limits(max_connections=max_connections)

        # 业务逻辑重试次数 / Business logic retry count
        self._max_retries = max_retries
        # 底层连接重试次数 / Underlying connection retry count
        self.atransport = httpx.AsyncHTTPTransport(retries=max_retries)

        # 超时等待时间 / Timeout waiting time
        self._timeout = timeout
        self.timeout = httpx.Timeout(timeout)
        # 异步客户端 / Asynchronous http_client
        self.aclient = httpx.AsyncClient(
            headers=self.client_headers,
            proxies=self.proxies,
            timeout=self.timeout,
            limits=self.limits,
            transport=self.atransport,
        )

    async def fetch_response(self, endpoint: str) -> Response:
        """获取数据 (Get data)

        Args:
            endpoint (str): 接口地址 (Endpoint URL)

        Returns:
            Response: 原始响应对象 (Raw response object)
        """
        return await self.get_fetch_data(f"{self.base_url}{endpoint}")

    async def fetch_get_json(self, endpoint: str) -> Union[dict, List[Any]]:
        """获取 JSON 数据 (Get JSON data)

        Args:
            endpoint (str): 接口地址 (Endpoint URL)

        Returns:
            dict: 解析后的JSON数据 (Parsed JSON data)
        """
        response = await self.get_fetch_data(f"{self.base_url}{endpoint}")
        return self.parse_json(response)

    async def fetch_post_json(self, endpoint: str, params: dict = {}, data=None) -> Union[dict, List[Any]]:
        """获取 JSON 数据 (Post JSON data)

        Args:
            endpoint (str): 接口地址 (Endpoint URL)

        Returns:
            dict: 解析后的JSON数据 (Parsed JSON data)
        """
        response = await self.post_fetch_data(f"{self.base_url}{endpoint}", params, data)
        return self.parse_json(response)

    def parse_json(self, response: Response) -> Union[dict, List[Any]]:
        """解析 JSON 数据 (Parse JSON data)"""

        return response.json()

    async def get_fetch_data(self, url: str):
        """
        获取GET端点数据 (Get GET endpoint data)

        Args:
            url (str): 端点URL (Endpoint URL)

        Returns:
            response: 响应内容 (Response content)
        """
        for attempt in range(self._max_retries):
            try:
                response = await self.aclient.get(url, follow_redirects=True)
                if not response.text.strip() or not response.content:
                    error_message = "第 {0} 次响应内容为空, 状态码: {1}, URL:{2}".format(attempt + 1,
                                                                                         response.status_code,
                                                                                         response.url)

                    logger.warning(error_message)

                    if attempt == self._max_retries - 1:
                        raise APIRetryExhaustedError(
                            "获取端点数据失败, 次数达到上限"
                        )

                    await asyncio.sleep(self._timeout)
                    continue

                # logger.info("响应状态码: {0}".format(response.status_code))
                response.raise_for_status()
                return response

            except httpx.RequestError:
                raise APIConnectionError("连接端点失败，检查网络环境或代理：{0} 代理：{1} 类名：{2}"
                                         .format(url, self.proxies, self.__class__.__name__)
                                         )

            except httpx.HTTPStatusError as http_error:
                self.handle_http_status_error(http_error, url, attempt + 1)

            except APIError as e:
                e.display_error()

    async def post_fetch_data(self, url: str, params: dict = {}, data=None):
        """
        获取POST端点数据 (Get POST endpoint data)

        Args:
            url (str): 端点URL (Endpoint URL)
            params (dict): POST请求参数 (POST request parameters)

        Returns:
            response: 响应内容 (Response content)
        """
        for attempt in range(self._max_retries):
            try:
                response = await self.aclient.post(
                    url,
                    json=None if not params else dict(params),
                    data=None if not data else data,
                    follow_redirects=True
                )
                if not response.text.strip() or not response.content:
                    error_message = "第 {0} 次响应内容为空, 状态码: {1}, URL:{2}".format(attempt + 1,
                                                                                         response.status_code,
                                                                                         response.url)

                    logger.warning(error_message)

                    if attempt == self._max_retries - 1:
                        raise APIRetryExhaustedError(
                            "获取端点数据失败, 次数达到上限"
                        )

                    await asyncio.sleep(self._timeout)
                    continue

                # logger.info("响应状态码: {0}".format(response.status_code))
                response.raise_for_status()
                return response

            except httpx.RequestError:
                raise APIConnectionError(
                    "连接端点失败，检查网络环境或代理：{0} 代理：{1} 类名：{2}".format(url, self.proxies,
                                                                                   self.__class__.__name__)
                )

            except httpx.HTTPStatusError as http_error:
                self.handle_http_status_error(http_error, url, attempt + 1)

            except APIError as e:
                e.display_error()

    async def head_fetch_data(self, url: str):
        """
        获取HEAD端点数据 (Get HEAD endpoint data)

        Args:
            url (str): 端点URL (Endpoint URL)

        Returns:
            response: 响应内容 (Response content)
        """
        try:
            response = await self.aclient.head(url)
            # logger.info("响应状态码: {0}".format(response.status_code))
            response.raise_for_status()
            return response

        except httpx.RequestError:
            raise APIConnectionError("连接端点失败，检查网络环境或代理：{0} 代理：{1} 类名：{2}".format(
                url, self.proxies, self.__class__.__name__
            )
            )

        except httpx.HTTPStatusError as http_error:
            self.handle_http_status_error(http_error, url, 1)

        except APIError as e:
            e.display_error()

    def handle_http_status_error(self, http_error, url: str, attempt):
        """
        处理HTTP状态错误 (Handle HTTP status error)

        Args:
            http_error: HTTP状态错误 (HTTP status error)
            url: 端点URL (Endpoint URL)
            attempt: 尝试次数 (Number of attempts)
        Raises:
            APIConnectionError: 连接端点失败 (Failed to connect to endpoint)
            APIResponseError: 响应错误 (Response error)
            APIUnavailableError: 服务不可用 (Service unavailable)
            APINotFoundError: 端点不存在 (Endpoint does not exist)
            APITimeoutError: 连接超时 (Connection timeout)
            APIUnauthorizedError: 未授权 (Unauthorized)
            APIRateLimitError: 请求频率过高 (Request frequency is too high)
            APIRetryExhaustedError: 重试次数达到上限 (The number of retries has reached the upper limit)
        """
        response = getattr(http_error, "response", None)
        response_text = getattr(response, "text", None)
        status_code = getattr(response, "status_code", None)

        if response is None or status_code is None:
            logger.error("HTTP状态错误: {0}, URL: {1}, 尝试次数: {2}".format(
                http_error, url, attempt
            )
            )
            raise APIResponseError(f"处理HTTP错误时遇到意外情况: {http_error}")

        if status_code == 302:
            pass
        elif status_code == 404:
            raise APINotFoundError(f"HTTP Status Code {status_code}, check your URL")
        elif status_code == 503:
            raise APIUnavailableError(f"HTTP Status Code {status_code}")
        elif status_code == 408:
            raise APITimeoutError(f"HTTP Status Code {status_code}")
        elif status_code == 401:
            raise APIUnauthorizedError(f"HTTP Status Code {status_code}, check your API key")
        elif status_code == 429:
            raise APIRateLimitError(f"HTTP Status Code {status_code}")
        else:
            logger.error("HTTP状态错误: {0}, URL: {1}, 尝试次数: {2}".format(
                status_code, url, attempt
            )
            )
            raise APIResponseError(f"\n程序出现异常，请检查错误信息。 | An error occurred in the program, please check the error message."
                                   f"\nHTTP Status Code: {status_code}"
                                   f"\nResponse: {response_text}"
                                   f"\nURL: {url}")

    async def close(self):
        await self.aclient.aclose()

    async def __aenter__(self):
        return self

    async def __aexit__(self, exc_type, exc_val, exc_tb):
        await self.aclient.aclose()



import datetime
from typing import Any, Optional

from fastapi import FastAPI
from pydantic import BaseModel, Field

app = FastAPI()


# 定义基础响应模型
class ResponseModel(BaseModel):
    code: int = Field(default=200, description="HTTP status code | HTTP状态码")
    router: str = Field(default="", description="The endpoint that generated this response | 生成此响应的端点")
    params: Any = Field(default={}, description="The parameters used in the request | 请求中使用的参数")
    data: Optional[Any] = Field(default=None, description="The response data | 响应数据")


# 定义错误响应模型
class ErrorResponseModel(BaseModel):
    code: int = Field(default=400, description="HTTP status code/HTTP状态码")
    message: str = Field(
        default="An error occurred, your account will not be charged for this request due to the error. | 服务器发生错误，您的帐户不会因此请求而被收费。",
        description="Error message | 错误消息")
    support: str = Field(
        default="Please contact us on Discord: https://discord.gg/aMEAS8Xsvz | 请在Discord上联系我们：https://discord.gg/aMEAS8Xsvz",
        description="Support message | 支持消息")
    time: str = Field(default=datetime.datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
                      description="The time the error occurred | 发生错误的时间")
    router: str = Field(default="", description="The endpoint that generated this response | 生成此响应的端点")
    params: dict = Field(default={}, description="The parameters used in the request | 请求中使用的参数")


# 定义会话数据模型
class SessionData(BaseModel):
    session_name: str
    scopes: list
    created_at: datetime.datetime
    expires_at: Optional[datetime.datetime]
    status: int


# 定义用户数据模型
class UserData(BaseModel):
    email: str
    balance: float
    free_credit: float
    email_verified: bool
    account_disabled: bool
    is_active: bool


# 定义用户信息响应模型
class UserInfoResponseModel(BaseModel):
    code: int = Field(default=200, description="HTTP status code | HTTP状态码")
    router: str = Field(default="", description="The endpoint that generated this response | 生成此响应的端点")
    session_data: SessionData
    user_data: UserData


if __name__ == "__main__":
    import uvicorn

    uvicorn.run(app, host="127.0.0.1", port=8000)



# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class TikTokAppV3:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据 | Get single video data
    async def fetch_one_video(self, aweme_id: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_one_video"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}")
        return data

    # 根据分享链接获取作品数据 | Get video data by sharing url
    async def fetch_one_video_by_share_url(self, share_url: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_one_video_by_share_url"
        data = await self.client.fetch_get_json(f"{endpoint}?share_url={share_url}")
        return data

    # 获取指定用户的信息 | Get information of specified user
    async def handler_user_profile(self, sec_user_id: str):
        endpoint = "/api/v1/tiktok/app/v3/handler_user_profile"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}")
        return data

    # 获取用户转发的作品数据 | Get user repost video data
    async def fetch_user_repost_videos(self, user_id: int, offset: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_repost_videos"
        data = await self.client.fetch_get_json(f"{endpoint}?user_id={user_id}&offset={offset}&count={count}")
        return data

    # 获取用户主页作品数据 | Get user homepage video data
    async def fetch_user_post_videos(self, sec_user_id: str, max_cursor: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_post_videos"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&count={count}")
        return data

    # 获取用户喜欢作品数据 | Get user like video data
    async def fetch_user_like_videos(self, sec_user_id: str, max_cursor: int, counts: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_like_videos"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&max_cursor={max_cursor}&counts={counts}")
        return data

    # 获取单个视频评论数据 | Get single video comments data
    async def fetch_video_comments(self, aweme_id: str, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_video_comments"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定视频的评论回复数据 | Get comment replies data of specified video
    async def fetch_video_comments_reply(self, item_id: str, comment_id: str, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_video_comment_replies"
        data = await self.client.fetch_get_json(
            f"{endpoint}?item_id={item_id}&comment_id={comment_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
    async def fetch_general_search_result(self, keyword: str, offset: int, count: int, sort_type: int,
                                          publish_time: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_general_search_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}")
        return data

    # 获取指定关键词的视频搜索结果 | Get video search results of specified keywords
    async def fetch_video_search_result(self, keyword: str, offset: int, count: int, sort_type: int, publish_time: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_video_search_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&sort_type={sort_type}&publish_time={publish_time}")
        return data

    # 获取指定关键词的用户搜索结果 | Get user search results of specified keywords
    async def fetch_user_search_result(self, keyword: str, offset: int, count: int, user_search_follower_count: str,
                                       user_search_profile_type: str, user_search_other_pref: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_search_result"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&offset={offset}&count={count}&user_search_follower_count={user_search_follower_count}&user_search_profile_type={user_search_profile_type}&user_search_other_pref={user_search_other_pref}")
        return data

    # 获取指定关键词的音乐搜索结果 | Get music search results of specified keywords
    async def fetch_music_search_result(self, keyword: str, offset: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_music_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定关键词的话题搜索结果 | Get hashtag search results of specified keywords
    async def fetch_hashtag_search_result(self, keyword: str, offset: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_hashtag_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定关键词的直播搜索结果 | Get live search results of specified keywords
    async def fetch_live_search_result(self, keyword: str, offset: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_live_search_result"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取指定音乐的详情数据 | Get details of specified music
    async def fetch_music_detail(self, music_id: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_music_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}")
        return data

    # 抖音音乐视频列表结果 | Get video list of specified music
    async def fetch_music_video_list(self, music_id: int, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_music_video_list"
        data = await self.client.fetch_get_json(f"{endpoint}?music_id={music_id}&cursor={cursor}&count={count}")
        return data

    # 抖音话题详情数据 | Get details of specified hashtag
    async def fetch_hashtag_detail(self, ch_id: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_hashtag_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?ch_id={ch_id}")
        return data

    # 获取指定话题的作品数据 | Get video list of specified hashtag
    async def fetch_hashtag_video_list(self, ch_id: int, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_hashtag_video_list"
        data = await self.client.fetch_get_json(f"{endpoint}?ch_id={ch_id}&cursor={cursor}&count={count}")
        return data

    # 获取指定用户的粉丝列表数据 | Get follower list of specified user
    async def fetch_user_follower_list(self, sec_user_id: str, count: int, max_time: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_follower_list"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&count={count}&max_time={max_time}")
        return data

    # 获取指定用户的关注列表数据 | Get following list of specified user
    async def fetch_user_following_list(self, sec_user_id: str, count: int, max_time: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_following_list"
        data = await self.client.fetch_get_json(
            f"{endpoint}?sec_user_id={sec_user_id}&count={count}&max_time={max_time}")
        return data

    # TikTok直播间排行榜 | Get live room ranking list
    async def fetch_live_room_rank_list(self, room_id: str, anchor_id: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_live_ranking_list"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}&anchor_id={anchor_id}")
        return data

    # 检测直播间是否在线 | Check if live room is online
    async def fetch_live_room_check(self, room_id: str):
        endpoint = "/api/v1/tiktok/app/v3/check_live_room_online"
        data = await self.client.fetch_get_json(f"{endpoint}?room_id={room_id}")
        return data

    # 获取分享短链接 | Get share short link
    async def fetch_share_short_link(self, url: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_share_short_link"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 获取分享二维码 | Get share QR code
    async def fetch_share_qr_code(self, url: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_share_qr_code"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 获取地点搜索结果 | Get location search results
    async def fetch_location_search(self, keyword: str, offset: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_location_search"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&offset={offset}&count={count}")
        return data

    # 获取商品搜索结果 | Get product search results
    async def fetch_product_search(self, keyword: str, cursor: int, count: int, sort_type: int,
                                   customer_review_four_star: bool, have_discount: bool, min_price: str,
                                   max_price: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_product_search"
        data = await self.client.fetch_get_json(
            f"{endpoint}?keyword={keyword}&cursor={cursor}&count={count}&sort_type={sort_type}&customer_review_four_star={customer_review_four_star}&have_discount={have_discount}&min_price={min_price}&max_price={max_price}")
        return data

    # 获取商品详情数据 | Get product detail data
    async def fetch_product_detail(self, product_id: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_product_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?product_id={product_id}")
        return data

    # 获取商品评价数据 | Get product review data
    async def fetch_product_review(self, product_id: str, cursor: int, size: int, filter_id: int, sort_type: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_product_review"
        data = await self.client.fetch_get_json(
            f"{endpoint}?product_id={product_id}&cursor={cursor}&size={size}&filter_id={filter_id}&sort_type={sort_type}")
        return data

    # 获取商家主页Page列表数据 | Get shop home page list data
    async def fetch_shop_home_page_list(self, sec_user_id: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_shop_home_page_list"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}")
        return data

    # 获取商家主页数据 | Get shop home page data
    async def fetch_shop_home(self, page_id: str, seller_id: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_shop_home"
        data = await self.client.fetch_get_json(f"{endpoint}?page_id={page_id}&seller_id={seller_id}")
        return data

    # 获取商家商品推荐数据 | Get shop product recommend data
    async def fetch_shop_product_recommend(self, seller_id: str, scroll_param: str, page_size: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_shop_product_recommend"
        data = await self.client.fetch_get_json(
            f"{endpoint}?seller_id={seller_id}&scroll_param={scroll_param}&page_size={page_size}")
        return data

    # 获取商家商品列表数据 | Get shop product list data
    async def fetch_shop_product_list(self, seller_id: str, scroll_params: str, page_size: int, sort_field: int,
                                      sort_order: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_shop_product_list"
        data = await self.client.fetch_get_json(
            f"{endpoint}?seller_id={seller_id}&scroll_params={scroll_params}&page_size={page_size}&sort_field={sort_field}&sort_order={sort_order}")
        return data

    # 获取商家信息数据 | Get shop information data
    async def fetch_shop_info(self, shop_id: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_shop_info"
        data = await self.client.fetch_get_json(f"{endpoint}?shop_id={shop_id}")
        return data

    # 获取商家产品分类数据 | Get shop product category data
    async def fetch_shop_product_category(self, seller_id: str):
        endpoint = "/api/v1/tiktok/app/v3/fetch_shop_product_category"
        data = await self.client.fetch_get_json(f"{endpoint}?seller_id={seller_id}")
        return data

    # 获取直播每日榜单数据 | Get live daily rank data
    async def fetch_live_daily_rank(self):
        endpoint = "/api/v1/tiktok/app/v3/fetch_live_daily_rank"
        data = await self.client.fetch_get_json(endpoint)
        return data

    # 获取用户音乐列表数据 | Get user music list data
    async def fetch_user_music_list(self, sec_user_id: str, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/app/v3/fetch_user_music_list"
        data = await self.client.fetch_get_json(f"{endpoint}?sec_user_id={sec_user_id}&cursor={cursor}&count={count}")
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw=="})

        tiktok_app_v3 = TikTokAppV3(client)

        # 获取单个作品数据 | Get single video data
        aweme_id = 6953663666666666666
        data = await tiktok_app_v3.fetch_one_video(aweme_id)
        print(data)

        # 获取指定用户的信息 | Get information of specified user
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        data = await tiktok_app_v3.handler_user_profile(sec_user_id)
        print(data)

        # 获取用户主页作品数据 | Get user homepage video data
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        max_cursor = 0
        count = 30
        data = await tiktok_app_v3.fetch_user_post_videos(sec_user_id, max_cursor, count)
        print(data)

        # 获取用户喜欢作品数据 | Get user like video data
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        max_cursor = 0
        counts = 30
        data = await tiktok_app_v3.fetch_user_like_videos(sec_user_id, max_cursor, counts)
        print(data)

        # 获取单个视频评论数据 | Get single video comments data
        aweme_id = "6953663666666666666"
        cursor = 0
        count = 30
        data = await tiktok_app_v3.fetch_video_comments(aweme_id, cursor, count)
        print(data)

        # 获取指定视频的评论回复数据 | Get comment replies data of specified video
        item_id = "6953663666666666666"
        comment_id = "6953663666666666666"
        cursor = 0
        count = 30
        data = await tiktok_app_v3.fetch_video_comments_reply(item_id, comment_id, cursor, count)
        print(data)

        # 获取指定关键词的综合搜索结果 | Get comprehensive search results of specified keywords
        keyword = "tiktok"
        offset = 0
        count = 30
        sort_type = 0
        publish_time = 0
        data = await tiktok_app_v3.fetch_general_search_result(keyword, offset, count, sort_type, publish_time)
        print(data)

        # 获取指定关键词的视频搜索结果 | Get video search results of specified keywords
        keyword = "tiktok"
        offset = 0
        count = 30
        sort_type = 0
        publish_time = 0
        data = await tiktok_app_v3.fetch_video_search_result(keyword, offset, count, sort_type, publish_time)
        print(data)

        # 获取指定关键词的用户搜索结果 | Get user search results of specified keywords
        keyword = "tiktok"
        offset = 0
        count = 30
        user_search_follower_count = ""
        user_search_profile_type = ""
        user_search_other_pref = ""
        data = await tiktok_app_v3.fetch_user_search_result(keyword, offset, count, user_search_follower_count,
                                                            user_search_profile_type, user_search_other_pref)
        print(data)

        # 获取指定关键词的音乐搜索结果 | Get music search results of specified keywords
        keyword = "tiktok"
        offset = 0
        count = 30
        data = await tiktok_app_v3.fetch_music_search_result(keyword, offset, count)
        print(data)

        # 获取指定关键词的话题搜索结果 | Get hashtag search results of specified keywords
        keyword = "tiktok"
        offset = 0
        count = 30
        data = await tiktok_app_v3.fetch_hashtag_search_result(keyword, offset, count)
        print(data)

        # 获取指定关键词的直播搜索结果 | Get live search results of specified keywords
        keyword = "tiktok"
        offset = 0
        count = 30
        data = await tiktok_app_v3.fetch_live_search_result(keyword, offset, count)
        print(data)

        # 获取指定音乐的详情数据 | Get details of specified music
        music_id = 6953663666666666666
        data = await tiktok_app_v3.fetch_music_detail(music_id)
        print(data)

        # 抖音音乐视频列表结果 | Get video list of specified music
        music_id = 6953663666666666666
        cursor = 0
        count = 30
        data = await tiktok_app_v3.fetch_music_video_list(music_id, cursor, count)
        print(data)

        # 抖音话题详情数据 | Get details of specified hashtag
        ch_id = 6953663666666666666
        data = await tiktok_app_v3.fetch_hashtag_detail(ch_id)
        print(data)

        # 获取指定话题的作品数据 | Get video list of specified hashtag
        ch_id = 6953663666666666666
        cursor = 0
        count = 30
        data = await tiktok_app_v3.fetch_hashtag_video_list(ch_id, cursor, count)
        print(data)

        # 获取指定用户的粉丝列表数据 | Get follower list of specified user
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        count = 30
        max_time = 0
        data = await tiktok_app_v3.fetch_user_follower_list(sec_user_id, count, max_time)
        print(data)

        # 获取指定用户的关注列表数据 | Get following list of specified user
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        count = 30
        max_time = 0
        data = await tiktok_app_v3.fetch_user_following_list(sec_user_id, count, max_time)
        print(data)

        # TikTok直播间排行榜 | Get live room ranking list
        room_id = "6953663666666666666"
        anchor_id = "6953663666666666666"
        data = await tiktok_app_v3.fetch_live_room_rank_list(room_id, anchor_id)
        print(data)

        # 检测直播间是否在线 | Check if live room is online
        room_id = "6953663666666666666"
        data = await tiktok_app_v3.fetch_live_room_check(room_id)
        print(data)

        # 获取分享短链接 | Get share short link
        url = "https://www.tiktok.com/@tiktok"
        data = await tiktok_app_v3.fetch_share_short_link(url)
        print(data)

        # 获取分享二维码 | Get share QR code
        url = "https://www.tiktok.com/@tiktok"
        data = await tiktok_app_v3.fetch_share_qr_code(url)
        print(data)

        # 获取地点搜索结果 | Get location search results
        keyword = "tiktok"
        offset = 0
        count = 30
        data = await tiktok_app_v3.fetch_location_search(keyword, offset, count)
        print(data)

        # 获取商品搜索结果 | Get product search results
        keyword = "tiktok"
        cursor = 0
        count = 30
        sort_type = 0
        customer_review_four_star = False
        have_discount = False
        min_price = "0"
        max_price = "1000"
        data = await tiktok_app_v3.fetch_product_search(keyword, cursor, count, sort_type, customer_review_four_star,
                                                        have_discount, min_price, max_price)
        print(data)

        # 获取商品详情数据 | Get product detail data
        product_id = "6953663666666666666"
        data = await tiktok_app_v3.fetch_product_detail(product_id)
        print(data)

        # 获取商品评价数据 | Get product review data
        product_id = "6953663666666666666"
        cursor = 0
        size = 30
        filter_id = 0
        sort_type = 0
        data = await tiktok_app_v3.fetch_product_review(product_id, cursor, size, filter_id, sort_type)
        print(data)

        # 获取商家主页Page列表数据 | Get shop home page list data
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        data = await tiktok_app_v3.fetch_shop_home_page_list(sec_user_id)
        print(data)

        # 获取商家主页数据 | Get shop home page data
        page_id = "6953663666666666666"
        seller_id = "6953663666666666666"
        data = await tiktok_app_v3.fetch_shop_home(page_id, seller_id)
        print(data)

        # 获取商家商品推荐数据 | Get shop product recommend data
        seller_id = "6953663666666666666"
        scroll_param = "6953663666666666666"
        page_size = 30
        data = await tiktok_app_v3.fetch_shop_product_recommend(seller_id, scroll_param, page_size)
        print(data)

        # 获取商家商品列表数据 | Get shop product list data
        seller_id = "6953663666666666666"
        scroll_params = "6953663666666666666"
        page_size = 30
        sort_field = 0
        sort_order = 0
        data = await tiktok_app_v3.fetch_shop_product_list(seller_id, scroll_params, page_size, sort_field, sort_order)
        print(data)

        # 获取商家信息数据 | Get shop information data
        shop_id = "6953663666666666666"
        data = await tiktok_app_v3.fetch_shop_info(shop_id)
        print(data)

        # 获取商家产品分类数据 | Get shop product category data
        seller_id = "6953663666666666666"
        data = await tiktok_app_v3.fetch_shop_product_category(seller_id)
        print(data)

        # 获取直播每日榜单数据 | Get live daily rank data
        data = await tiktok_app_v3.fetch_live_daily_rank()
        print(data)

        # 获取用户音乐列表数据 | Get user music list data
        sec_user_id = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        cursor = 0
        count = 30
        data = await tiktok_app_v3.fetch_user_music_list(sec_user_id, cursor, count)
        print(data)


    asyncio.run(main())



import threading
import time
import logging
from rich.logging import RichHandler


class Singleton(type):
    _instances = {}  # 存储实例的字典
    _lock: threading.Lock = threading.Lock()  # 线程锁

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def __call__(cls, *args, **kwargs):
        """
        重写默认的类实例化方法。当尝试创建类的一个新实例时，此方法将被调用。
        如果已经有一个与参数匹配的实例存在，则返回该实例；否则创建一个新实例。
        """
        key = (cls, args, frozenset(kwargs.items()))
        with cls._lock:
            if key not in cls._instances:
                instance = super().__call__(*args, **kwargs)
                cls._instances[key] = instance
        return cls._instances[key]

    @classmethod
    def reset_instance(cls, *args, **kwargs):
        """
        重置指定参数的实例。这只是从 _instances 字典中删除实例的引用，
        并不真正删除该实例。如果其他地方仍引用该实例，它仍然存在且可用。
        """
        key = (cls, args, frozenset(kwargs.items()))
        with cls._lock:
            if key in cls._instances:
                del cls._instances[key]


class LogManager(metaclass=Singleton):
    def __init__(self):
        if getattr(self, "_initialized", False):  # 防止重复初始化
            return

        self.logger = logging.getLogger("TikHub_API_SDK")
        self.logger.setLevel(logging.INFO)
        self.log_dir = None
        self._initialized = True

    def setup_logging(self, level=logging.INFO, log_to_console=False):
        self.logger.handlers.clear()
        self.logger.setLevel(level)

        if log_to_console:
            ch = RichHandler(
                show_time=False,
                show_path=False,
                markup=True,
                keywords=(RichHandler.KEYWORDS or []) + ["STREAM"],
                rich_tracebacks=True,
            )
            ch.setFormatter(logging.Formatter("{message}", style="{", datefmt="[%X]"))
            self.logger.addHandler(ch)

    def shutdown(self):
        for handler in self.logger.handlers:
            handler.close()
            self.logger.removeHandler(handler)
        self.logger.handlers.clear()
        time.sleep(1)  # 确保文件被释放


def log_setup(log_to_console=True):
    logger = logging.getLogger("TikHub_Python_SDK")
    if logger.hasHandlers():
        # logger已经被设置，不做任何操作
        return logger

    # 创建临时的日志目录
    # temp_log_dir = Path("./logs")
    # temp_log_dir.mkdir(exist_ok=True)

    # 初始化日志管理器
    log_manager = LogManager()
    log_manager.setup_logging(
        level=logging.INFO, log_to_console=log_to_console
    )

    return logger


logger = log_setup()



from pydantic import BaseModel, Field
from typing import List


# 列表作品
class URL_List(BaseModel):
    urls: List[str] = [
        "https://test.example.com/xxxxx/",
        "https://test.example.com/yyyyy/",
        "https://test.example.com/zzzzz/"
    ]


# abogus API响应模型
class A_Bogus_Parameters(BaseModel):
    url: str = Field("https://www.douyin.com/aweme/v1/web/general/search/single/?device_platform=webapp&aid=6383&channel=channel_pc_web&search_channel=aweme_general&enable_history=1&keyword=%E4%B8%AD%E5%8D%8E%E5%A8%98&search_source=normal_search&query_correct_type=1&is_filter_search=0&from_group_id=7346905902554844468&offset=0&count=15&need_filter_settings=1&pc_client_type=1&version_code=190600&version_name=19.6.0&cookie_enabled=true&screen_width=1280&screen_height=800&browser_language=zh-CN&browser_platform=Win32&browser_name=Firefox&browser_version=124.0&browser_online=true&engine_name=Gecko&engine_version=124.0&os_name=Windows&os_version=10&cpu_core_num=16&device_memory=&platform=PC&webid=7348962975497324070&msToken=YCTVM6YGmjFdIpQAN9ykXLBXiSiuHdZkOkEQWTeqVOHBEPmOcM0lNwE0Kd9vgHPMPigSndZDHfAq9k-6lDmH3Jqz6mHHxmn-BzQjmLMIfLIPgirgnOixM9x4PwgcNQ%3D%3D",
                     description='url，需要使用urlencode(data, safe="*")进行编码')

    data: str = Field("", description='body，需要使用urlencode(data, safe="*")进行编码')

    user_agent: str = Field(
        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/104.0.0.0 Safari/537.36",
        description='user-agent')
    index_0: int = Field(0, description='加密明文列表的第一个值，无特殊要求，默认为0')
    index_1: int = Field(1, description='加密明文列表的第一个值，无特殊要求，默认为1')
    index_2: int = Field(14, description='加密明文列表的第一个值，无特殊要求，默认为14')







class APIError(Exception):
    """
    基本API异常类，其他API异常都会继承这个类

    Base API exception class, all other API exceptions will inherit this class
    """

    def __init__(self, status_code=None):
        self.status_code = status_code
        print(
            "程序出现异常，请检查错误信息。 | An error occurred in the program, please check the error message."
        )

    def display_error(self):
        """
        显示错误信息和状态码（如果有的话）

        Display the error message and status code (if any)
        """
        return f"Error: {self.args[0]}." + (
            f" Status Code: {self.status_code}." if self.status_code else ""
        )


class APIConnectionError(APIError):
    """
    当与API的连接出现问题时抛出

    Raised when there is a problem connecting to the API
    """

    def display_error(self):
        return f"API Connection Error: {self.args[0]}."


class APIUnavailableError(APIError):
    """
    当API服务不可用时抛出，例如维护或超时

    Raised when the API service is unavailable, such as maintenance or timeout
    """

    def display_error(self):
        return f"API Unavailable Error: {self.args[0]}."


class APINotFoundError(APIError):
    """
    当API端点不存在时抛出

    Raised when the API endpoint does not exist
    """

    def display_error(self):
        return f"API Not Found Error: {self.args[0]}."


class APIResponseError(APIError):
    """
    当API返回的响应与预期不符时抛出

    Raised when the response returned by the API does not match the expected
    """

    def display_error(self):
        return f"API Response Error: {self.args[0]}."


class APIRateLimitError(APIError):
    """
    当达到API的请求速率限制时抛出

    Raised when the request rate limit of the API is reached
    """

    def display_error(self):
        return f"API Rate Limit Error: {self.args[0]}."


class APITimeoutError(APIError):
    """
    当API请求超时时抛出

Raised when the API request times out
    """

    def display_error(self):
        return f"API Timeout Error: {self.args[0]}."


class APIUnauthorizedError(APIError):
    """
    当API请求由于授权失败而被拒绝时抛出

    Raised when an API request is denied due to authorization failure
    """

    def display_error(self):
        return f"API Unauthorized Error: {self.args[0]}."


class APIRetryExhaustedError(APIError):
    """
    当API请求重试次数用尽时抛出

    Raised when the API request retry count is exhausted
    """

    def display_error(self):
        return f"API Retry Exhausted Error: {self.args[0]}."



# 导入API SDK Client类
import json

from tikhub.http_client.api_client import APIClient


class TikTokWeb:

    # 初始化 | Initialize
    def __init__(self, client: APIClient):
        self.client = client

    # 获取单个作品数据 | Get single video data
    async def fetch_post_detail(self, item_id: str):
        endpoint = "/api/v1/tiktok/web/fetch_post_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?itemId={item_id}")
        return data

    # 获取用户的个人信息 | Get user profile
    async def fetch_user_profile(self, secUid: str, uniqueId: str = None):
        endpoint = "/api/v1/tiktok/web/fetch_user_profile"
        data = await self.client.fetch_get_json(f"{endpoint}?secUid={secUid}&uniqueId={uniqueId}")
        return data

    # 获取用户的作品列表 | Get user posts
    async def fetch_user_post(self, secUid: str, cursor: int, count: int, coverFormat: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_post"
        data = await self.client.fetch_get_json(f"{endpoint}?secUid={secUid}&cursor={cursor}&count={count}&coverFormat={coverFormat}")
        return data

    # 获取用户的点赞列表 | Get user likes
    async def fetch_user_like(self, secUid: str, cursor: int, count: int, coverFormat: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_like"
        data = await self.client.fetch_get_json(f"{endpoint}?secUid={secUid}&cursor={cursor}&count={count}&coverFormat={coverFormat}")
        return data

    # 获取用户的收藏列表 | Get user favorites
    async def fetch_user_collect(self, cookie: str, secUid: str, cursor: int, count: int, coverFormat: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_collect"
        data = await self.client.fetch_get_json(f"{endpoint}?cookie={cookie}&secUid={secUid}&cursor={cursor}&count={count}&coverFormat={coverFormat}")
        return data

    # 获取用户的播放列表 | Get user play list
    async def fetch_user_play_list(self, secUid: str, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_play_list"
        data = await self.client.fetch_get_json(f"{endpoint}?secUid={secUid}&cursor={cursor}&count={count}")
        return data

    # 获取用户的合辑列表 | Get user mix list
    async def fetch_user_mix(self, mixId: str, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_mix"
        data = await self.client.fetch_get_json(f"{endpoint}?mixId={mixId}&cursor={cursor}&count={count}")
        return data

    # 获取作品的评论列表 | Get video comments
    async def fetch_post_comment(self, aweme_id: str, cursor: int, count: int, current_region: str):
        endpoint = "/api/v1/tiktok/web/fetch_post_comment"
        data = await self.client.fetch_get_json(f"{endpoint}?aweme_id={aweme_id}&cursor={cursor}&count={count}&current_region={current_region}")
        return data

    # 获取作品的评论回复列表 | Get video comment replies
    async def fetch_post_comment_reply(self, item_id: str, comment_id: str, cursor: int, count: int, current_region: str):
        endpoint = "/api/v1/tiktok/web/fetch_post_comment_reply"
        data = await self.client.fetch_get_json(f"{endpoint}?item_id={item_id}&comment_id={comment_id}&cursor={cursor}&count={count}&current_region={current_region}")
        return data

    # 获取用户的粉丝列表 | Get user followers
    async def fetch_user_fans(self, secUid: str, count: int, maxCursor: int, minCursor: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_fans"
        data = await self.client.fetch_get_json(f"{endpoint}?secUid={secUid}&count={count}&maxCursor={maxCursor}&minCursor={minCursor}")
        return data

    # 获取用户的关注列表 | Get user followings
    async def fetch_user_follow(self, secUid: str, count: int, maxCursor: int, minCursor: int):
        endpoint = "/api/v1/tiktok/web/fetch_user_follow"
        data = await self.client.fetch_get_json(f"{endpoint}?secUid={secUid}&count={count}&maxCursor={maxCursor}&minCursor={minCursor}")
        return data

    # 获取综合搜索列表 | Get general search list
    async def fetch_general_search(self, keyword: str, count: int, offset: int):
        endpoint = "/api/v1/tiktok/web/fetch_general_search"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&count={count}&offset={offset}")
        return data

    # 搜索关键字推荐 | Search keyword suggest
    async def fetch_search_keyword_suggest(self, keyword: str):
        endpoint = "/api/v1/tiktok/web/fetch_search_keyword_suggest"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}")
        return data

    # 搜索用户 | Search user
    async def fetch_search_user(self, keyword: str, cursor: int):
        endpoint = "/api/v1/tiktok/web/fetch_search_user"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&cursor={cursor}")
        return data

    # 搜索视频 | Search video
    async def fetch_search_video(self, keyword: str, count: int, offset: int):
        endpoint = "/api/v1/tiktok/web/fetch_search_video"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&count={count}&offset={offset}")
        return data

    # 搜索直播 | Search live
    async def fetch_search_live(self, keyword: str, count: int, offset: int):
        endpoint = "/api/v1/tiktok/web/fetch_search_live"
        data = await self.client.fetch_get_json(f"{endpoint}?keyword={keyword}&count={count}&offset={offset}")
        return data

    # Tag详情 | Tag detail
    async def fetch_tag_detail(self, tag_name: str):
        endpoint = "/api/v1/tiktok/web/fetch_tag_detail"
        data = await self.client.fetch_get_json(f"{endpoint}?tag_name={tag_name}")
        return data

    # Tag作品列表 | Tag post list
    async def fetch_tag_post(self, challengeID: str, cursor: int, count: int):
        endpoint = "/api/v1/tiktok/web/fetch_tag_post"
        data = await self.client.fetch_get_json(f"{endpoint}?challengeID={challengeID}&cursor={cursor}&count={count}")
        return data

    # 生成真实msToken | Generate real msToken
    async def fetch_real_msToken(self):
        endpoint = "/api/v1/tiktok/web/generate_real_msToken"
        data = await self.client.fetch_get_json(endpoint)
        return data

    # 生成ttwid | Generate ttwid
    async def fetch_ttwid(self, cookie: str):
        endpoint = "/api/v1/tiktok/web/generate_ttwid"
        data = await self.client.fetch_get_json(f"{endpoint}?cookie={cookie}")
        return data

    # 生成xbogus | Generate xbogus
    async def gen_xbogus(self, url: str, user_agent: str):
        endpoint = "/api/v1/tiktok/web/generate_xbogus"
        data = await self.client.fetch_post_json(endpoint, data={"url": url, "user_agent": user_agent})
        return data

    # 提取用户sec_user_id | Extract user sec_user_id
    async def get_sec_user_id(self, url: str):
        endpoint = "/api/v1/tiktok/web/get_sec_user_id"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 提取列表用户sec_user_id | Extract list user sec_user_id
    async def get_all_sec_user_id(self, url: list):
        endpoint = "/api/v1/tiktok/web/get_all_sec_user_id"
        data = await self.client.fetch_post_json(endpoint, data={"url": url})
        return data

    # 提取单个作品id | Extract single video id
    async def get_aweme_id(self, url: str):
        endpoint = "/api/v1/tiktok/web/get_aweme_id"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 提取列表作品id | Extract list video id
    async def get_all_aweme_id(self, url: list):
        endpoint = "/api/v1/tiktok/web/get_all_aweme_id"
        data = await self.client.fetch_post_json(endpoint, data={"url": url})
        return data

    # 获取用户unique_id | Get user unique_id
    async def get_unique_id(self, url: str):
        endpoint = "/api/v1/tiktok/web/get_unique_id"
        data = await self.client.fetch_get_json(f"{endpoint}?url={url}")
        return data

    # 提取列表unique_id列表 | Get list unique_id
    async def get_all_unique_id(self, url: list):
        endpoint = "/api/v1/tiktok/web/get_all_unique_id"
        data = await self.client.fetch_post_json(endpoint, data={"url": url})
        return data


if __name__ == "__main__":
    import asyncio


    async def main():
        client = APIClient(base_url="http://127.0.0.1:8000", client_headers={
            "Authorization": "Bearer l7sVQFh64V8ltC8fzEaNtWE60zVSopDLlpVX62fArT1FznsPds9+2RGoXw=="})

        tiktok_web = TikTokWeb(client)

        # 获取单个作品数据 | Get single video data
        item_id = "6952419395722484486"
        data = await tiktok_web.fetch_post_detail(item_id)
        print(data)

        # 获取用户的个人信息 | Get user profile
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        uniqueId = None
        data = await tiktok_web.fetch_user_profile(secUid, uniqueId)
        print(data)

        # 获取用户的作品列表 | Get user posts
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        cursor = 0
        count = 30
        coverFormat = 1
        data = await tiktok_web.fetch_user_post(secUid, cursor, count, coverFormat)
        print(data)

        # 获取用户的点赞列表 | Get user likes
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        cursor = 0
        count = 30
        coverFormat = 1
        data = await tiktok_web.fetch_user_like(secUid, cursor, count, coverFormat)
        print(data)

        # 获取用户的收藏列表 | Get user favorites
        cookie = ""
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        cursor = 0
        count = 30
        coverFormat = 1
        data = await tiktok_web.fetch_user_collect(cookie, secUid, cursor, count, coverFormat)
        print(data)

        # 获取用户的播放列表 | Get user play list
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        cursor = 0
        count = 30
        data = await tiktok_web.fetch_user_play_list(secUid, cursor, count)

        # 获取用户的合辑列表 | Get user mix list
        mixId = "6952419395722484486"
        cursor = 0
        count = 30
        data = await tiktok_web.fetch_user_mix(mixId, cursor, count)
        print(data)

        # 获取作品的评论列表 | Get video comments
        aweme_id = "6952419395722484486"
        cursor = 0
        count = 30
        current_region = "CN"
        data = await tiktok_web.fetch_post_comment(aweme_id, cursor, count, current_region)
        print(data)

        # 获取作品的评论回复列表 | Get video comment replies
        item_id = "6952419395722484486"
        comment_id = "6952419395722484486"
        cursor = 0
        count = 30
        current_region = "CN"
        data = await tiktok_web.fetch_post_comment_reply(item_id, comment_id, cursor, count, current_region)
        print(data)

        # 获取用户的粉丝列表 | Get user followers
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        count = 30
        maxCursor = 0
        minCursor = 0
        data = await tiktok_web.fetch_user_fans(secUid, count, maxCursor, minCursor)
        print(data)

        # 获取用户的关注列表 | Get user followings
        secUid = "MS4wLjABAAAAv7iSuuXDJGDvJkmH_vz1qkDZYo1apxgzaxdBSeIuPiM"
        count = 30
        maxCursor = 0
        minCursor = 0
        data = await tiktok_web.fetch_user_follow(secUid, count, maxCursor, minCursor)
        print(data)

        # 获取综合搜索列表 | Get general search list
        keyword = "tiktok"
        count = 30
        offset = 0
        data = await tiktok_web.fetch_general_search(keyword, count, offset)
        print(data)

        # 搜索关键字推荐 | Search keyword suggest
        keyword = "tiktok"
        data = await tiktok_web.fetch_search_keyword_suggest(keyword)
        print(data)

        # 搜索用户 | Search user
        keyword = "tiktok"
        cursor = 0
        data = await tiktok_web.fetch_search_user(keyword, cursor)
        print(data)

        # 搜索视频 | Search video
        keyword = "tiktok"
        count = 30
        offset = 0
        data = await tiktok_web.fetch_search_video(keyword, count, offset)
        print(data)

        # 搜索直播 | Search live
        keyword = "tiktok"
        count = 30
        offset = 0
        data = await tiktok_web.fetch_search_live(keyword, count, offset)
        print(data)

        # 生成真实msToken | Generate real msToken
        data = await tiktok_web.fetch_real_msToken()
        print(data)

        # 生成ttwid | Generate ttwid
        cookie = ""
        data = await tiktok_web.fetch_ttwid(cookie)
        print(data)

        # 生成xbogus | Generate xbogus
        url = ""
        user_agent = ""
        data = await tiktok_web.gen_xbogus(url, user_agent)
        print(data)

        # 提取用户sec_user_id | Extract user sec_user_id
        url = ""
        data = await tiktok_web.get_sec_user_id(url)
        print(data)

        # 提取列表用户sec_user_id | Extract list user sec_user_id
        url = []
        data = await tiktok_web.get_all_sec_user_id(url)
        print(data)

        # 提取单个作品id | Extract single video id
        url = ""
        data = await tiktok_web.get_aweme_id(url)
        print(data)

        # 提取列表作品id | Extract list video id
        url = []
        data = await tiktok_web.get_all_aweme_id(url)
        print(data)

        # 获取用户unique_id | Get user unique_id
        url = ""
        data = await tiktok_web.get_unique_id(url)
        print(data)

        # 提取列表unique_id列表 | Get list unique_id
        url = []
        data = await tiktok_web.get_all_unique_id(url)
        print(data)





